@@ -136,9 +136,21 @@ class Builder(object):
         output.writeln("class %s(Struct):" % c_name)
         output.indent()
         output.writeln('"""Wrap `%s`"""' % c_name)
+
+        # Write struct properties as @property for better documentation
+        for name in declaration.fldnames or []:
+            output.writeln("@property")
+            output.writeln("def %s(self): return self.cdata.%s" % (name, name))
+            output.writeln("@%s.setter" % name)
+            output.writeln("def %s(self, value): self.cdata.%s = value" % (name, name))
+
+        # Add associated functions to struct:
         functions = self.declarations_by_type[c_name + " *"]
         for fname in functions:
-            short_name = fname[4].lower() + fname[5:]
+            if fname[5].isupper():
+                short_name = fname[4:]
+            else:
+                short_name = fname[4].lower() + fname[5:]
             output.writeln("%s = %s" % (short_name, fname))
         if not functions:
             output.writeln("pass")
