@@ -74,7 +74,7 @@ def main():
     rwops = 0
 
     # Initialize variables
-    audio_rate = 22050
+    audio_rate = 22050*2
     audio_format = AUDIO_S16
     audio_channels = 2
     audio_buffers = 4096
